==> dfauditor-0.0.3-py3-none-any.whl: dfauditor/auditor.py <==
import logging
from multiprocessing import Pool, cpu_count
import dfauditor.extractor
import psutil
import pandas as pd

import dfauditor.app_logger

log = dfauditor.app_logger.get(log_level=logging.INFO)


def profile_number_columns(series_items):
    log.debug('name: {}; row.count: {}; used: {}% free: {:.2f}GB'.format(series_items[0],
                                                                         len(series_items[1].index),
                                                                         psutil.virtual_memory().percent,
                                                                         float(
                                                                             psutil.virtual_memory().free) / 1024 ** 3))
    dict_1 = dfauditor.extractor.numeric(series_items[1]).__dict__
    dict_1.update(dfauditor.extractor.decile_bins(series_items[1]).__dict__)

    return dict_1


def profile_string_columns(series_items):
    log.debug('name: {}; row.count: {}; used: {}% free: {:.2f}GB'.format(series_items[0],
                                                                         len(series_items[1].index),
                                                                         psutil.virtual_memory().percent,
                                                                         float(
                                                                             psutil.virtual_memory().free) / 1024 ** 3))
    return dfauditor.extractor.string(series_items[1]).__dict__


def profile_decile_bins(series_items):
    log.debug('name: {}; row.count: {}; used: {}% free: {:.2f}GB'.format(series_items[0],
                                                                         len(series_items[1].index),
                                                                         psutil.virtual_memory().percent,
                                                                         float(
                                                                             psutil.virtual_memory().free) / 1024 ** 3))
    return dfauditor.extractor.decile_bins(series_items[1]).__dict__


def audit_dataframe(dataframe, nr_processes=None):
    """
    produce a profile of the dataframe
    :param dataframe: a pandas dataframe
    :param nr_processes: a integer value specifying the number of processes to use (ideally #{processes}<#{cpus})
    :return: a json body containing the derived metrics
    """
    if not nr_processes:
        num_processes = min(dataframe.shape[1], cpu_count())

        with Pool(num_processes) as pool:
            columns = dataframe.columns
            log.debug('auditing dataframe with {} rows and {} columns'.format(
                len(dataframe.index),
                len(columns)))
            # using generic numpy type labels
            number_df = dataframe.select_dtypes(include=['number'])
            string_df = dataframe.select_dtypes(include=['object'])
            # bin_df = dataframe.select_dtypes(include=['number'])

            res_list = pool.map(profile_number_columns, number_df.iteritems())
            res_list += pool.map(profile_string_columns, string_df.iteritems())
            # res_list += pool.map(profile_decile_bins, bin_df.iteritems())
            return res_list

==> dfauditor-0.0.4-py3-none-any.whl: dfauditor/auditor.py <==
import logging
from multiprocessing import Pool, cpu_count

import pandas as pd
import psutil

import dfauditor.app_logger
import dfauditor.extractor

log = dfauditor.app_logger.get(log_level=logging.INFO)


def profile_number_columns(series_items):
    log.debug('name: {}; row.count: {}; used: {}% free: {:.2f}GB'.format(series_items[0],
                                                                         len(series_items[1].index),
                                                                         psutil.virtual_memory().percent,
                                                                         float(
                                                                             psutil.virtual_memory().free) / 1024 ** 3))
    return dfauditor.extractor.numeric(series_items[1]).__dict__


def profile_string_columns(series_items):
    log.debug('name: {}; row.count: {}; used: {}% free: {:.2f}GB'.format(series_items[0],
                                                                         len(series_items[1].index),
                                                                         psutil.virtual_memory().percent,
                                                                         float(
                                                                             psutil.virtual_memory().free) / 1024 ** 3))
    return dfauditor.extractor.string(series_items[1]).__dict__


def profile_proba_bins(series_items, bins=10):
    log.debug('name: {}; row.count: {}; used: {}% free: {:.2f}GB'.format(series_items[0],
                                                                         len(series_items[1].index),
                                                                         psutil.virtual_memory().percent,
                                                                         float(
                                                                             psutil.virtual_memory().free) / 1024 ** 3))
    return dfauditor.extractor.bins(series_items[1], size=bins).__dict__


def audit_dataframe(dataframe, nr_processes=None, proba_col_bins=[]):
    """
    produce a profile of the dataframe 
    :param dataframe: a pandas dataframe 
    :param nr_processes: a integer value specifying the number of processes to use (ideally #{processes}<#{cpus}) 
    :param proba_col_bins: a list of tuples (column_name, nr_of_bins) - e.g. ('score', 10) 
        would give you ten bins on the score column 
    :return: a json body containing the derived metrics
    """
    if not isinstance(dataframe, pd.DataFrame):
        raise TypeError('Currently only supports panda dataframes')
    if not nr_processes:
        num_processes = min(dataframe.shape[1], cpu_count())

        with Pool(num_processes) as pool:
            columns = dataframe.columns
            log.debug('auditing dataframe with {} rows and {} columns'.format(
                len(dataframe.index),
                len(columns)))
            # using generic numpy type labels
            number_df = dataframe.select_dtypes(include=['number'])
            string_df = dataframe.select_dtypes(include=['object'])

            res_list = pool.map(profile_number_columns, number_df.iteritems())
            res_list += pool.map(profile_string_columns, string_df.iteritems())
            if proba_col_bins:
                # change the shape of list of tuples [(name_i, bins_i),...] to
                #   [(name_0, ..., name_n), (bins_0, ..., bins_n)]
                proba_col_bins_t = list(zip(*proba_col_bins))
                res_list += pool.starmap(profile_proba_bins,
                                         zip(dataframe[list(proba_col_bins_t[0])].iteritems(),
                                             list(proba_col_bins_t[1])
                                             )
                                         )
            return res_list
